#!/bin/sh
#
# Hackery on Crosswalk texts *other than* NASB w/Strong's.
# assumes: a directory structure of chapters, {OT,NT}/Book/.orig/XXX.
#
# MAKE YOUR OWN INSTANCE.  DON'T REDISTRIBUTE WHAT THESE TOOLS GENERATE.
# that is, *PERSONAL USE*, on the basis of publicly-distributed material.
# bible.org controls content and delivery, and this is proper and legit.
# you control what you do with it on your own machine.
# but you mustn't ship the result anywhere else.
#
histogram=no
limit=all
while [ "$1" != "" ] ; do
    case "$1" in
	-[0-9]|-[0-9][0-9])
	    limit=$[0-($1)]
	    shift
	    ;;
	-h) histogram=yes
	    shift
	    ;;
	-*) echo 'Usage: hack [-h] [-STAGE] FILELIST'
	    exit 1
	    ;;
	*)  break
	    ;;
    esac
done
#
if [ "$histogram" = no -a ! -s nt ] ; then
    echo "Consider the -h (histogram) option."
    echo "Re-run with same args to disregard this recommendation."
    echo random text > nt
    exit 1
fi
#
export _POSIX2_VERSION=199209	# to get sane tail behavior.
b="`basename $PWD`"
#
if [ $# = 0 ] ; then
    set -- ??/*/.orig/???	# both testaments, all books, all chapters.
fi
c="$#"
if [ $c -lt 60 ] ; then
    histogram=no
else
    mod=$[($c+59)/60]
    if [ $c = 0 ] ; then
	c=1
    fi
fi
#
# Histogram prep.
if [ "$histogram" = yes ] ; then
    echo Limit = "$limit", "$c" ch, "#" = "$mod" ch.
    count=0
    echo -n "$b |"
fi
#
# Generate.
for i in $* ; do
    if [ "$histogram" = yes ] ; then
	count=$[$count+1]
	if [ $[$count % $mod] = 1 ] ; then
	    echo -n '#'
	fi
    else
	echo $i
    fi
    tr -d '\r' < $i |
    egrep '<B><I>[0-9]*</I></B>|<A NAME="[FR]' |
    # the 2nd & 3rd "s|<FONT..." expressions were recommended to take
    # care of recent changes in CW's content of NRSV. --kk, 17 may 07.
    sed -e 's/^.*<br><TABLE[^>]*>//' \
	-e 's/&nbsp;/ /g' \
	-e 's/  */ /g' \
	-e 's|<FONT face="Arial, Geneva, Helvetica" SIZE="2"><BLOCKQUOTE>\( <P>\)\?\(.*\)</BLOCKQUOTE></FONT>|\2|' \
	-e 's|<FONT face="Arial, Geneva, Helvetica" SIZE="2"><BLOCKQUOTE> \?<P>||g' \
	-e 's|<FONT face="Arial, Geneva, Helvetica" SIZE="2"><BLOCKQUOTE>||g' \
	-e 's|<TR[^>]*><TD[^>]*>||g' \
	-e 's|</TD></TR>|\r|g' \
	-e 's|<N[1234]>||g' |
    tr '\r\227' '\n-' |
    egrep '<B><I>[0-9]*</I></B>|<A NAME="[FR]' > ${i//.orig/}
done
#
# Histogram prep.
if [ "$histogram" = yes ] ; then
    echo "|"
    count=0
    echo -n "$b |"
fi
#
# Hack.
if [ "$limit" = all ] ; then
    limit=99
fi
for i in $* ; do
    f=${i//.orig}
    if [ "$histogram" = yes ] ; then
	count=$[$count+1]
	if [ $[$count % $mod] = 1 ] ; then
	    echo -n '#'
	fi
    else
	echo $b $f
    fi
    #
    # 1 - Split verses.
    if [ "$limit" -ge 1 ] ; then
	sed -e "s| <B><I>\([0-9]\+\)</I></B> |\r\1 |g" < $f |
	tr '\r' '\n' |
	sed -e '/^ *$/d' > $f.2
	mv $f.2 $f
    fi
    #
    # 2 - Insert book/chapter and normalize paragraphs.
    if [ "$limit" -ge 2 ] ; then
	book="${f%%//[0-9][0-9][0-9]}"
	book="${book##?T/}"
	chapter="`echo ${f##*/} | sed -e 's/^0*//'`"	# leading zero removal
	sed -e "s|^\([0-9]\)|$book ${chapter}:\1|" < $f \
	    -e 's| *<P> *$|<p />|' > $f.2
	mv $f.2 $f
    fi
    #
    # 3 - Normalize footnote content.
    if [ "$limit" -ge 3 ] ; then
	sed -e 's;<font[^>]*><HR[^>]*><B>\(FOOTNOTES\|CROSS REFERENCES\):</B><br>\(<FONT [^>]*>\)\?;;g' < $f \
	    -e 's|<A NAME="R[0-9]\+">R\([0-9]\+\): <I>\(.*\)$|c.\1 <i>\2</i>|g' \
	    -e '/^c\./s;</\?i>\|<A HREF=[^>]*>\|</A>;;g' \
	    -e 's|<A NAME="F[0-9]\+">F\([0-9]\+\): <I>\(.*[^ ]\) \?$|f.\1 <i>\2</i>|g' > $f.2
	mv $f.2 $f
    fi
    #
    # 4 - Reduce footnote references in text.
    if [ "$limit" -ge 4 ] ; then
	sed -e 's| <A HREF="#F[0-9]\+"><FONT SIZE="1"><SUP>F\([0-9]\+\)</SUP></FONT></A>|<note>\1</note>|g' < $f \
	    -e 's| <A HREF="#R[0-9]\+"><FONT SIZE="1"><SUP>R\([0-9]\+\)</SUP></FONT></A>|<scripRef>\1</scripRef>|g' < $f \
	    -e 's|\( [0-9]\+:[0-9]\+\)<note>|\1 <note>|' > $f.2
	mv $f.2 $f
    fi
    #
    # 5 - Make footnotes & xrefs.
    if [ "$limit" -ge 5 ] ; then
	grep '^f\.' $f | sed -e 's|^f\.||' |
	while read note text ; do
	  sed -e "s_<note>$note</note>_<note>F$note: $text</note>_g" < $f > $f.2
	  mv $f.2 $f
	done
	grep '^c\.' $f | sed -e 's|^c\.||' |
	while read note text ; do
	  sed -e "s_<scripRef>$note</scripRef>_<scripRef>$text</scripRef>_g" < $f > $f.2
	  mv $f.2 $f
	done
    fi
    #
    # 6 - NoFNText
    if [ "$limit" -ge 6 ] ; then
	grep -v '^[fc]\.' < $f > $f.2
	mv $f.2 $f
    fi
    #
    # 7 - Correct some paragraph mishaps.
    if [ "$limit" -ge 7 ] ; then
	sed -e "s|<p> *<p />|<p />|" < $f \
	    -e 's|<p>|<p />|' > $f.2
	mv $f.2 $f
    fi
done
#
if [ "$histogram" = yes ] ; then
    echo "|"
fi
#
if [ "$limit" = 99 ] ; then
    cat `cat ../scripts/list | sed -e 's;$;/???;'` > ALL
    if [ "$histogram" = yes ] ; then
	echo -n "$b |Swordifying..."
    else
	wc -l ALL
    fi
    vpl2mod ALL . 1 2>&1 | egrep -v '^from file: |^adding entry: '
    rm ALL
    chmod go+r ?t{,.vss}
    if [ "$histogram" = yes ] ; then
	echo "complete.|"
    fi
fi
exit 0
